Index: src/ia32/code-stubs-ia32.cc |
=================================================================== |
--- src/ia32/code-stubs-ia32.cc (revision 12500) |
+++ src/ia32/code-stubs-ia32.cc (working copy) |
@@ -4170,15 +4170,15 @@ |
Immediate(factory->fixed_array_map())); |
// Set length. |
__ mov(FieldOperand(ebx, FixedArray::kLengthOffset), ecx); |
// Fill contents of fixed-array with the-hole. |
__ SmiUntag(ecx); |
- __ mov(edx, Immediate(factory->the_hole_value())); |
+ __ mov(edx, Immediate(factory->undefined_value())); |
__ lea(ebx, FieldOperand(ebx, FixedArray::kHeaderSize)); |
// Fill fixed array elements with hole. |
// eax: JSArray. |
// ecx: Number of elements to fill. |
// ebx: Start of elements in FixedArray. |
- // edx: the hole. |
+ // edx: undefined. |
Label loop; |
__ test(ecx, ecx); |
__ bind(&loop); |
@@ -4170,15 +4170,15 @@ |
// Set length. |
__ mov(FieldOperand(ebx, FixedArray::kLengthOffset), ecx); |
- // Fill contents of fixed-array with the-hole. |
+ // Fill contents of fixed-array with undefined. |
__ SmiUntag(ecx); |
@@ -4170,15 +4170,15 @@ |
__ lea(ebx, FieldOperand(ebx, FixedArray::kHeaderSize)); |
- // Fill fixed array elements with hole. |
+ // Fill fixed array elements with undefined. |
// eax: JSArray. |
// ecx: Number of elements to fill. |